#
# spec file for package python-PySDL2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         X_display         ":98"
%define lname pysdl2
Name:           python-PySDL2
Version:        0.9.17
Release:        1.1
Summary:        Python ctypes wrapper around SDL2
License:        SUSE-Public-Domain
URL:            https://github.com/py-sdl/py-sdl2
Source:         https://files.pythonhosted.org/packages/source/p/%{lname}/%{lname}-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  SDL2 >= 2.0.22
BuildRequires:  SDL2_gfx >= 1.0.4
BuildRequires:  SDL2_image >= 2.6.0
BuildRequires:  SDL2_mixer >= 2.6.0
BuildRequires:  SDL2_ttf >= 2.20.0
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module pytest}
BuildRequires:  libmpg123-0
BuildRequires:  xorg-x11-server
# /SECTION
Requires:       SDL2 >= 2.0.22
Requires:       SDL2_gfx >= 1.0.4
Requires:       SDL2_image >= 2.6.0
Requires:       SDL2_mixer >= 2.6.0
Requires:       SDL2_ttf >= 2.20.0
BuildArch:      noarch
%python_subpackages

%description
PySDL2 is a pure Python wrapper around the SDL2, SDL2_mixer, SDL2_image,
SDL2_ttf, and SDL2_gfx libraries. Instead of relying on C code, it uses
the built-in ctypes module to interface with SDL2, and provides simple
Python classes and wrappers for common SDL2 functionality.

%prep
%autosetup -p1 -n %{lname}-%{version}

sed -i 's/\r$//' AUTHORS.txt COPYING.txt README.md
find . -name *DS_Store -delete

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export SDL_VIDEODRIVER=dummy
export SDL_AUDIODRIVER=dummy
export SDL_RENDER_DRIVER=software
export PYTHONFAULTHANDLER=1

%pytest -rfEs

%files %{python_files}
%license COPYING.txt
%doc AUTHORS.txt README.md doc/
%{python_sitelib}/sdl2
%{python_sitelib}/PySDL2-%{version}*-info

%changelog
* Tue Mar  4 2025 Markéta Machová <mmachova@suse.com>
- Update to 0.9.17
  * Updated to wrap new functions and constants in SDL 2.30.10.
  * Updated to wrap new functions and constants in SDL_mixer 2.8.0
  * Updated to wrap new function in SDL_image 2.8.0.
  * Added a new function sdl2.ext.get_key_state for checking if a given
    key is currently down or up independently of the SDL event queue.
- Drop merged patches:
  * fix-tests-SDL_GetError.patch
  * fix-partially-resolve-video_test.patch
  * fix-test-SDL_hid_enumerate.patch
* Fri Feb  2 2024 munix9@googlemail.com
- Add libmpg123-0 as a build requirement for the tests
* Sun Aug 20 2023 munix9@googlemail.com
- Remove fix-tests.patch in favor of upstream patches
- Add upstream patches to resolve test failures:
  fix-partially-resolve-video_test.patch
  fix-test-SDL_hid_enumerate.patch
  fix-tests-SDL_GetError.patch
* Sun Jul 16 2023 munix9@googlemail.com
- Update to 0.9.16:
  * Updated to wrap new functions and constants in SDL 2.28.0.
  * Added a new method to sdl2.ext.Renderer, Renderer.rcopy(), for
    drawing textures to the renderer with relative alignment.
  * Added a new module, sdl2.ext.input for processing common SDL
    input events in a Pythonic manner.
  * Added a new function sdl2.ext.quit_requested() for checking
    whether an SDL event queue contains any sdl2.SDL_QUIT events.
- Update to 0.9.15:
  * Updated to wrap new functions and constants in SDL 2.26.0.
  * Added a new module sdl2.ext.mouse for showing/hiding/moving/
    retrieving the mouse cursor and querying the current state of
    the mouse buttons.
  * Added indexing/unpacking support to the sdl2.ext.Point and
    sdl2.ext.Rect classes and their float equivalents.
  * Updated sdl2.ext.SpriteFactory.from_image() to allow passing
    PIL.Image.Image objects directly.
  * Improved sdl2.ext.Texture performance.
  * Fixed a bug preventing SDL Points and Rects from being used
    as srcrect or dstrect for sdl2.ext.Renderer.copy().
  * Added a binding for SDL_ResetHint, which was added in SDL
    2.24.0 but got missed in PR #246.
- Adjust fix-tests.patch
- Remove fix-version_test.patch (fixed upstream)
- Remove python-PySDL2.rpmlintrc (obsolete)
* Sat Nov 26 2022 munix9@googlemail.com
- Add fix-version_test.patch (gh#py-sdl/py-sdl2#248):
  Don't assert that SDL_GetRevision() starts with http
- Skip rpmlint error python-tests-in-package
* Wed Nov  2 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove .DS_Store files from sources
- Remove not needed python_module macro definition
* Wed Nov  2 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-tests.patch to fix the test run in the rpmbuild container without
  access to /dev/input.
* Wed Nov  2 2022 munix9@googlemail.com
- Update to 0.9.14:
  * Updated to wrap new functions and constants in SDL 2.24.0.
  * Added a new module sdl2.ext.displays for retrieving and working
    with connected displays and their supported resolutions/refresh
    rates.
  * Extended sdl2.ext.init to allow initializing all SDL subsystems
    individually (previously just initialized the video subsystem).
  * Improved the memory safety of the sdl2.ext.Window class.
  * Added raise_sdl_err to the public ext API.
  * Fixed sdl2.ext.line to work correctly on 1bpp surfaces.
  * Various fixes/improvements to the unit test suite for Linux
    package maintainers.
- Remove mixer_tests_fix.patch (fixed upstream)
* Fri Jul 29 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.9.13:
  - Updated to wrap new functions and constants in SDL_ttf
    2.20.0.
  - Updated to wrap new functions and constants in SDL_mixer
    2.6.0.
  - Updated to wrap new functions and constants in SDL_image
    2.6.0.
  - Added experimental bindings for the new functions and
    constants in the SDL 2.23.1 pre-release.
  - Added a new function :func:sdl2.ext.load_svg that allows
    loading simple SVG images at arbitrary resolutions with
    SDL_image 2.6.0 or later.
  - Added bindings for new functions and constants introduced in
    SDL2 2.0.22
  - Added a stable API for accessing the raw ctypes function
    objects for SDL2 functions
  - Various bugfixes (see the project's news.rst for more info)
- Add mixer_tests_fix.patch to switch off failing tests
  (gh#py-sdl/py-sdl2#241).
- Otherwise, we actually don’t need to explicitly skip ANY
  tests! Wow!
* Sun Mar 20 2022 Ben Greiner <code@bnavigator.de>
- Update to version 0.9.11
  * Added bindings for new functions and constants introduced in
    SDL2 2.0.20
  * Added bindings and documentation for new functions and
    constants introduced in SDL2_ttf 2.0.18
- Changelog for Release 0.9.10
  * Added bindings for new functions and constants introduced in
    SDL2 2.0.18
  * Added experimental support for SDL 2.0.3 and 2.0.4 for older
    platforms (tested on an iMac G4 running 10.4.11)
  * Major improvements to the ext.pixelaccess module
  * Major rewrite of the ext.image module
  * New object-oriented method of rendering with sdl2.ext.Renderers
    using the new sdl2.ext.Texture class
  * Major expansion and rewrite of the sdl2.ext.Renderer class
  * New powerful sdl2.ext.FontTTF class for font rendering
  * Redocumented most of the sdl2.ext modules for better clarity
    and maintainability
  * Added automatic detection of Homebrew SDL2 binaries on Apple
    Silicon Macs as a fallback Deprecated a number of sdl2.ext
    modules and functions
- Changelog for Release 0.9.9
  * Added bindings for new functions and constants introduced in
    SDL2 2.0.16
  * Reverted the fix for issue #139 which inadvertently caused
    Window.show() to force the window to use SDL2's software
    rendering, breaking the Renderer class and compatibility with
    PyOpenGL.
- Drop PySDL2-pr193-skipnumpy.patch
- Clean out test suite
* Sun Aug 29 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.9.8
  * This release fixes a number of bugs, updates the bindings to
    support new functions in SDL2 2.0.14, adds a wrapper for the
    SDL2 MessageBox API, and more.
  * Added bindings for new functions and constants introduced in
    SDL2 2.0.12 and 2.0.14
  * Added full support for SDL2 binaries in non-system locations
    (e.g., with pysdl2-dll) when using PySDL2 with Python installed
    from the Microsoft Store on Windows.
  * Improved handling of SDL2 binaries that are too old to be used
    with PySDL2.
  * Added a new sdl2.ext API for displaying SDL2 MessageBox alerts
    and dialog boxes.
- Add PySDL2-pr193-skipnumpy.patch (gh#marcusva/py-sdl2#193) for
  missing NumPy in python36
* Mon Feb  8 2021 Ben Greiner <code@bnavigator.de>
- remove duplicate check section: Only the Xvfb version runs
  without segfaults when loading the SDL libraries. (Except for
  two flaky Window position and size tests)
* Fri Mar 27 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.9.7
  * The minimum required SDL version is 2.0.5
  * The minimum required SDL_ttf version is 2.0.14
  * The minimum required SDL_mixer version is 2.0.1
  * The minimum required SDL_image version is 2.0.1
  * Improved compatibility with older SDL2 releases by raising informative
  exceptions whenever a function requiring a newer SDL2 binary is called
  * fixed bug preventing use of background color with wrapped text using
  :meth:`sdl2.ext.FontManager.render()` (PR #134)
  * fixed issue #112: allow easy moving and resizing of :obj:`sdl2.ext.Window()`
  objects through 'position' and 'size' attributes, added 'open' and 'close'
  methods to Window objects
  * fixed issue #130: SDL_RW* functions now accept pointers to RW objects
  * fixed issue #135: :func:`sdl2.SDL_GetPrefPath()` and
  :func:`sdl2.SDL_GetPrefPath()` now return bytestrings instead of pointers
  to strings.
  * fixed issue #148: added support for loading SDL2 .so binaries with numeric
  suffixes on Unix-like OSes (e.g. 'libSDL2.so.2')
  * fixed transparency issues with pallete indexed PNGs (PR #159)
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Nov  7 2017 toddrme2178@gmail.com
- initial version
